\name{HiC_HMRF_Bayes}
\alias{HiC_HMRF_Bayes}
\title{
Hi-C HMRF Bayes Peak Caller Based On R Data Matrix 
}
\description{
The function of running HiC HMRF Bayes peak caller based on expected frequency matrix and observed frequency matrix.
}
\usage{
HiC_HMRF_Bayes(U, E, burnIn = 5000, iter = 5000, verbose = 1)
}

\arguments{
  \item{U}{ 
	observed frequency matrix, which is a square matrix. Only upper-triangle entries are used. If an entry in the upper triangle is NA, the function will fetch the entry from its corresponding lower triangle. If both entries are NA, the function will output the message that "Observed frequencies can not contain NAs" and return NULL to indicate false data format. 
}
  \item{E}{
	expected frequency matrix, which is a square matrix. Only upper-triangle entries are used. If an entry in the upper triangle is NA or 0, the function will fetch the entry from its corresponding lower triangle. If both entries are NA or 0, the function will output the message that Expected frequencies can not contain NAs or 0's and return NULL to indicate false data format. 
}
  \item{burnIn}{
	the number of simulations not used in final results averaging as the BurnIn in Bayesian method.
}
  \item{iter}{
	the number of simulations after the burn-ins. For example, if burnin=4000 and iter=8000, out \code{HiC_HMRF_Bayes} will run 12000 simulations.
}
  \item{verbose}{
	a logical variable controlling whether the intermediate results are reported for each 200 simulations. If true, the function will report the estimated parameters in each 200 simulations. If false, not reported.
}
}
\details{
	The function of running Hi-C HMRF Bayes peak caller based on expected frequency matrix and observed frequency matrix
}
\value{
A list including three items.
  \item{posterior.probability}{The estimated peak probability matrix by our HMRF-Bayes method.}
  \item{expected.count}{The matrix of expected frequencies.}
  \item{observed.count}{The matrix of observed frequencies.}
  \item{theta.estimate}{The value of estimated parameter theta.}
  \item{phi.estimate}{The value of estimated parameter phi.}
  \item{psi.estimate}{The value of estimated parameter psi.}
}
\references{
Xu et al, A hidden Markov random field based Bayesian method for the detection of long_range chromosomal interactions in Hi_C Data, Manuscript.
}
\author{
Zheng Xu
}

\examples{
## An example of loading data, run peak caller and output results. 
## Our toy example of HiC data for fragment 15060-15069.
 HiC.Data=HiC_Prepare_Matrix(file="toyHiC_frag15060_15069.txt",
    verbose=TRUE,sep="\t",header=TRUE)
 HiC.Results=HiC_HMRF_Bayes(HiC.Data$ObservedCountMatrix, 
    HiC.Data$ExpectedCountMatrix, 
    burnIn = 5000, iter = 5000, verbose=1)
 HiC_Output(HiCResults=HiC.Results,fragIDs=HiC.Data$fragIDs,
    probfile="toyHiC_frag15060_15069_Results.txt",
    estimatorfile="toyHiC_frag15060_15069_Estimated_Parameters.txt")
}

\keyword{ HiC_HMRF_Bayes }

