\name{HiC_Plot_Heatmap}
\alias{HiC_Plot_Heatmap}
\title{
HiC Plot Heatmap From File
}
\description{
\code{HiC_Plot_Heatmap} load data into the memory from file, plot the heatmap based on score.  
}
\usage{
HiC_Plot_Heatmap=function(file, index=c(1,2,3),sep = "\t", 
	header = TRUE,verbose = TRUE,negative.log10.scale=FALSE,
	xlab = "", ylab = "", main = "",cex.main=1,cex.lab=1, 
	col=matlab.like(100))
}

\arguments{
  \item{file}{
 the file to be loaded, which is a text file, separated by the separator. 
}
   \item{index}{
 the column index to be loaded for fragment 1, fragment 2 and score. For example, \code{index=c(2,3,4)} means column 2,3,4 are respectively for fragment 1, fragment 2 and score. 
}
  \item{sep}{
  the field separator character. Values on each line of the file are separated by this character. 
}
  \item{header}{
 a logical value indicating whether the file contains the names of the variables as its first line. If missing, the value is determined from the file format: header is set to TRUE if and only if the first row contains one fewer field than the number of columns.
}
 \item{verbose}{
 a logical value, controlling whether the function be verbose in loading the data, reporting the number of observations loaded or be silent (not report).
}
 \item{negative.log10.scale}{
 a logical value, controlling whether to apply the negative log10 transformation to the data. This usually applies for the heatmap of p value in the test.
}
 \item{x.lab}{
 the label of x axis.
}
 \item{y.lab}{
 the label of y axis.
}
 \item{main}{
 the label of the plot title.
}
 \item{cex.main}{
 the font size of the label of the plot title.
}
 \item{cex.lab}{
 the font size of the label of the x axis and y axis.
}
 \item{col}{
 the gradient color used in heatmap. The gradient color is from colorRamps package, which can take blue2red(n), blue2green(n), green2red(n), blue2yellow(n), cyan2yellow(n), magenta2green(n), matlab.like(n), matlab.like2(n), blue2green2red(n), primary.colors(n, steps = 3, no.white = TRUE), rgb.tables and table.ramp. For more details, please refer to colorRamps package. 
}

}
\details{
\code{HiC_Plot_Heatmap} load data into the memory from file, plot the heatmap based on score. 
}
\value{
No return values. The function will report error message if get some errors.
}
\references{
Xu et al, A hidden Markov random field based Bayesian method for the detection of long-range chromosomal interactions in Hi-C Data, Manuscript
}
\author{
  Zheng Xu
}
\keyword{HiC_Plot_Heatmap}

\examples{
## For our toy example of HiC data for fragment 15060-15069.

## Plot the heatmap of observed frequency 
## which is at column 3 of the HiC data file.
HiC_Plot_Heatmap(file="toyHiC_frag15060_15069.txt",index=c(1,2,3),
      verbose=TRUE,sep="\t",header=TRUE,negative.log10.scale=FALSE,
	  xlab="Fragment Index",ylab="Fragment Index",main="Observed Frequency")

## Plot the heatmap of expected frequency 
## which is at column 4 of the HiC data file.
HiC_Plot_Heatmap(file="toyHiC_frag15060_15069.txt",index=c(1,2,4),
      verbose=TRUE,sep="\t",header=TRUE,negative.log10.scale=FALSE,
	  xlab="Fragment Index",ylab="Fragment Index",main="Expected Frequency")

## Plot the heatmap of posterior probability 
## which is at column 5 of the HiC result file.
HiC_Plot_Heatmap(file="toyHiC_frag15060_15069_Results.txt",index=c(1,2,5),
      verbose=TRUE,sep="\t",header=TRUE,negative.log10.scale=FALSE,
	  xlab="Fragment Index",ylab="Fragment Index",main="Posterior Probability")
}

